@@ -116,3 +116,32 @@ class TestExists:
         self, predicate: Predicate[object], iterable: Iterable
     ) -> None:
         assert collection.exists(predicate)(iterable) is False
+
+
+class TestEvery:
+    @pytest.mark.parametrize(
+        "predicate, iterable",
+        [
+            (generic.identical(1), [1, 1, 1]),
+            (generic.identical(1), []),
+            (numeric.greater(0), [1, 2]),
+            (generic.equal("a"), "aa"),
+        ],
+    )
+    def test_returns_true_for_complete_iterable(
+        self, predicate: Predicate[object], iterable: Iterable
+    ) -> None:
+        assert collection.every(predicate)(iterable) is True
+
+    @pytest.mark.parametrize(
+        "predicate, iterable",
+        [
+            (generic.identical(...), [..., "b", "c"]),
+            (numeric.greater(1), [-3, 0, 1, 0, 2]),
+            (generic.equal("a"), "abc"),
+        ],
+    )
+    def test_returns_false_for_incomplete_iterable(
+        self, predicate: Predicate[object], iterable: Iterable
+    ) -> None:
+        assert collection.every(predicate)(iterable) is False
